==> activity-common-api-1.3.48-sources.jar: cn/com/duiba/activity/common/center/api/params/wallet/RedAccCustomSaveParam.java <==
package cn.com.duiba.activity.common.center.api.params.wallet;

import cn.com.duiba.activity.common.center.api.enums.CurrencyTypeEnum;
import cn.com.duiba.activity.common.center.api.enums.WithdrawLimitTypeEnum;
import cn.com.duiba.activity.common.center.api.enums.WithdrawTimeRewardTypeEnum;
import cn.com.duiba.api.enums.ActivityUniformityTypeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaoxuda on 2019/1/22.
 */
public class RedAccCustomSaveParam implements Serializable {
    private static final long serialVersionUID = 1780436823695018993L;

    /**周期所属appId**/
    private Long appId;

    /**业务类型，1：红包广场**/
    private ActivityUniformityTypeEnum relType;

    /**业务ID**/
    private Long relId;

    /**奖励额度，单位：分**/
    private Long bonusLimit;

    /**提现限制类型，1：固定金额，2：最低门槛**/
    private WithdrawLimitTypeEnum withdrawLimitType;

    /**固定提现金额，单位：分**/
    private Long withdrawFixedCount;
    /**
     * 提现金额门槛，单位：分
     */
    private Long withdrawThreshold;

    /**提现次数限制类型，1：固定赠送，2：连续访问赠送**/
    private WithdrawTimeRewardTypeEnum timeRewardType;

    /**提现次数固定赠送值**/
    private Integer timeRewardFixedCount;

    /**提现次数连续访问赠送条件，连续访问天数**/
    private Integer timeRewardThreshold;

    /**周期开始时间**/
    private Date startTime;

    /**周期结束时间**/
    private Date endTime;

    /**
     * 货币类型
     * @see CurrencyTypeEnum
     */
    private Integer currencyType;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public ActivityUniformityTypeEnum getRelType() {
        return relType;
    }

    public void setRelType(ActivityUniformityTypeEnum relType) {
        this.relType = relType;
    }

    public Long getRelId() {
        return relId;
    }

    public void setRelId(Long relId) {
        this.relId = relId;
    }

    public Long getBonusLimit() {
        return bonusLimit;
    }

    public void setBonusLimit(Long bonusLimit) {
        this.bonusLimit = bonusLimit;
    }

    public WithdrawLimitTypeEnum getWithdrawLimitType() {
        return withdrawLimitType;
    }

    public void setWithdrawLimitType(WithdrawLimitTypeEnum withdrawLimitType) {
        this.withdrawLimitType = withdrawLimitType;
    }

    public Long getWithdrawFixedCount() {
        return withdrawFixedCount;
    }

    public void setWithdrawFixedCount(Long withdrawFixedCount) {
        this.withdrawFixedCount = withdrawFixedCount;
    }

    public Long getWithdrawThreshold() {
        return withdrawThreshold;
    }

    public void setWithdrawThreshold(Long withdrawThreshold) {
        this.withdrawThreshold = withdrawThreshold;
    }

    public WithdrawTimeRewardTypeEnum getTimeRewardType() {
        return timeRewardType;
    }

    public void setTimeRewardType(WithdrawTimeRewardTypeEnum timeRewardType) {
        this.timeRewardType = timeRewardType;
    }

    public Integer getTimeRewardFixedCount() {
        return timeRewardFixedCount;
    }

    public void setTimeRewardFixedCount(Integer timeRewardFixedCount) {
        this.timeRewardFixedCount = timeRewardFixedCount;
    }

    public Integer getTimeRewardThreshold() {
        return timeRewardThreshold;
    }

    public void setTimeRewardThreshold(Integer timeRewardThreshold) {
        this.timeRewardThreshold = timeRewardThreshold;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getCurrencyType() {
        return currencyType;
    }

    public void setCurrencyType(Integer currencyType) {
        this.currencyType = currencyType;
    }
}

==> activity-common-api-1.4.31-sources.jar: cn/com/duiba/activity/common/center/api/params/wallet/RedAccCustomSaveParam.java <==
package cn.com.duiba.activity.common.center.api.params.wallet;

import cn.com.duiba.activity.common.center.api.enums.CurrencyTypeEnum;
import cn.com.duiba.activity.common.center.api.enums.WithdrawLimitTypeEnum;
import cn.com.duiba.activity.common.center.api.enums.WithdrawTimeRewardTypeEnum;
import cn.com.duiba.api.enums.ActivityUniformityTypeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xiaoxuda on 2019/1/22.
 */
public class RedAccCustomSaveParam implements Serializable {
    private static final long serialVersionUID = 1780436823695018993L;

    /**周期所属appId**/
    private Long appId;

    /**业务类型，1：红包广场**/
    private ActivityUniformityTypeEnum relType;

    /**业务ID**/
    private Long relId;

    /**奖励额度，单位：分**/
    private Long bonusLimit;

    /**提现限制类型，1：固定金额，2：最低门槛**/
    private WithdrawLimitTypeEnum withdrawLimitType;

    /**固定提现金额，单位：分**/
    private Long withdrawFixedCount;
    /**
     * 提现金额门槛，单位：分
     */
    private Long withdrawThreshold;

    /**提现次数限制类型，1：固定赠送，2：连续访问赠送**/
    private WithdrawTimeRewardTypeEnum timeRewardType;

    /**提现次数固定赠送值**/
    private Integer timeRewardFixedCount;

    /**提现次数连续访问赠送条件，连续访问天数**/
    private Integer timeRewardThreshold;

    //提现环境
    private Integer withdrawEnvType;

    /**周期开始时间**/
    private Date startTime;

    /**周期结束时间**/
    private Date endTime;

    /**
     * 货币类型
     * @see CurrencyTypeEnum
     */
    private Integer currencyType;

    /**
     * 货币子类型
     * @see cn.com.duiba.activity.common.center.api.enums.SubCurrencyTypeEnum
     */
    private Integer subCurrencyType;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public ActivityUniformityTypeEnum getRelType() {
        return relType;
    }

    public void setRelType(ActivityUniformityTypeEnum relType) {
        this.relType = relType;
    }

    public Long getRelId() {
        return relId;
    }

    public void setRelId(Long relId) {
        this.relId = relId;
    }

    public Long getBonusLimit() {
        return bonusLimit;
    }

    public void setBonusLimit(Long bonusLimit) {
        this.bonusLimit = bonusLimit;
    }

    public WithdrawLimitTypeEnum getWithdrawLimitType() {
        return withdrawLimitType;
    }

    public void setWithdrawLimitType(WithdrawLimitTypeEnum withdrawLimitType) {
        this.withdrawLimitType = withdrawLimitType;
    }

    public Long getWithdrawFixedCount() {
        return withdrawFixedCount;
    }

    public void setWithdrawFixedCount(Long withdrawFixedCount) {
        this.withdrawFixedCount = withdrawFixedCount;
    }

    public Long getWithdrawThreshold() {
        return withdrawThreshold;
    }

    public void setWithdrawThreshold(Long withdrawThreshold) {
        this.withdrawThreshold = withdrawThreshold;
    }

    public WithdrawTimeRewardTypeEnum getTimeRewardType() {
        return timeRewardType;
    }

    public void setTimeRewardType(WithdrawTimeRewardTypeEnum timeRewardType) {
        this.timeRewardType = timeRewardType;
    }

    public Integer getTimeRewardFixedCount() {
        return timeRewardFixedCount;
    }

    public void setTimeRewardFixedCount(Integer timeRewardFixedCount) {
        this.timeRewardFixedCount = timeRewardFixedCount;
    }

    public Integer getTimeRewardThreshold() {
        return timeRewardThreshold;
    }

    public void setTimeRewardThreshold(Integer timeRewardThreshold) {
        this.timeRewardThreshold = timeRewardThreshold;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getCurrencyType() {
        return currencyType;
    }

    public void setCurrencyType(Integer currencyType) {
        this.currencyType = currencyType;
    }

    public Integer getWithdrawEnvType() {
        return withdrawEnvType;
    }

    public void setWithdrawEnvType(Integer withdrawEnvType) {
        this.withdrawEnvType = withdrawEnvType;
    }

    public Integer getSubCurrencyType() {
        return subCurrencyType;
    }

    public void setSubCurrencyType(Integer subCurrencyType) {
        this.subCurrencyType = subCurrencyType;
    }
}
